.. atmosphere:

Atmosphere
==========

.. autoclass:: sasktran2.Atmosphere

Internal Objects
----------------

.. autoclass:: sasktran2.AtmosphereStokes_1
.. autoclass:: sasktran2.AtmosphereStokes_3

.. autoclass:: sasktran2.AtmosphereStorageStokes_1
.. autoclass:: sasktran2.AtmosphereStorageStokes_3
